aboutsummaryrefslogtreecommitdiffstats
path: root/kernel/rcutree_plugin.h
diff options
context:
space:
mode:
Diffstat (limited to 'kernel/rcutree_plugin.h')
-rw-r--r--kernel/rcutree_plugin.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/kernel/rcutree_plugin.h b/kernel/rcutree_plugin.h
index 1d295c789d3d..c9f0c975c003 100644
--- a/kernel/rcutree_plugin.h
+++ b/kernel/rcutree_plugin.h
@@ -167,7 +167,7 @@ static int rcu_preempted_readers(struct rcu_node *rnp)
* irqs disabled, and this lock is released upon return, but irqs remain
* disabled.
*/
-static void task_quiet(struct rcu_node *rnp, unsigned long flags)
+static void rcu_report_unblock_qs_rnp(struct rcu_node *rnp, unsigned long flags)
__releases(rnp->lock)
{
unsigned long mask;
@@ -185,7 +185,7 @@ static void task_quiet(struct rcu_node *rnp, unsigned long flags)
* or tasks were kicked up to root rcu_node due to
* CPUs going offline.
*/
- cpu_quiet_msk_finish(&rcu_preempt_state, flags);
+ rcu_report_qs_rsp(&rcu_preempt_state, flags);
return;
}
@@ -193,7 +193,7 @@ static void task_quiet(struct rcu_node *rnp, unsigned long flags)
mask = rnp->grpmask;
spin_unlock(&rnp->lock); /* irqs remain disabled. */
spin_lock(&rnp_p->lock); /* irqs already disabled. */
- cpu_quiet_msk(mask, &rcu_preempt_state, rnp_p, flags);
+ rcu_report_qs_rnp(mask, &rcu_preempt_state, rnp_p, flags);
}
/*
@@ -253,12 +253,12 @@ static void rcu_read_unlock_special(struct task_struct *t)
/*
* If this was the last task on the current list, and if
* we aren't waiting on any CPUs, report the quiescent state.
* Note that task_quiet() releases rnp->lock.
*/
if (empty)
spin_unlock_irqrestore(&rnp->lock, flags);
else
- task_quiet(rnp, flags);
+ rcu_report_unblock_qs_rnp(rnp, flags);
} else {
local_irq_restore(flags);
}
@@ -566,7 +566,7 @@ static int rcu_preempted_readers(struct rcu_node *rnp)
#ifdef CONFIG_HOTPLUG_CPU
/* Because preemptible RCU does not exist, no quieting of tasks. */
-static void task_quiet(struct rcu_node *rnp, unsigned long flags)
+static void rcu_report_unblock_qs_rnp(struct rcu_node *rnp, unsigned long flags)
{
spin_unlock_irqrestore(&rnp->lock, flags);
}
@@ -253,12 +253,12 @@ static void rcu_read_unlock_special(struct task_struct *t)
* If this was the last task on the current list, and if
* we aren't waiting on any CPUs, report the quiescent state.
- * Note that task_quiet() releases rnp->lock.
+ * Note that rcu_report_unblock_qs_rnp() releases rnp->lock.
*/
if (empty)